@@ -11,6 +11,10 @@ from base64 import b64encode, b64decode
 from re import findall
 from colorama import init, Fore
 
+
+__version__ = "2.6.1"
+
+
 # 构造响应器
 check_state = on_fullmatch(msg="check state", permission=SUPERUSER, priority=5, block=True)
 set_port = on_regex(pattern=r'set_port:(?P<port>.*)', permission=SUPERUSER, priority=5, block=True)
@@ -33,10 +37,13 @@ switch = True
 # 初始化字体样式（自动重置字体样式）
 init(autoreset=True)
 
+logger.success(Fore.LIGHTGREEN_EX + f"成功导入本插件，插件版本为{__version__}")
+
 
 # 查看后端状态信息
 @check_state.handle()
 async def _():
+    await check_state.send(f"当前后端URL为：{post_url}，本地代理端口号为：{port}")
     logger.info(Fore.LIGHTCYAN_EX + f"当前后端URL为：{post_url}，本地代理端口号为：{port}")
 
 
@@ -44,27 +51,29 @@ async def _():
 @set_port.handle()
 async def _(regex: tuple = RegexGroup()):
     global port, proxies
-    port = regex[0]
+    pt = regex[0]
 
     # 判断是否为数字
     try:
-        int(port)
+        int(pt)
     except ValueError:
-        if port != "None":
+        # 取消代理模式
+        if pt == "None":
+            port = pt
+            proxies = None
+            logger.success(Fore.LIGHTCYAN_EX + "成功取消代理模式")
+            await set_port.finish("成功取消代理模式")
+        else:
             await set_port.finish("请输入有效参数！")
-
-    # 取消代理模式
-    if port == "None":
-        proxies = None
-        logger.success(Fore.LIGHTCYAN_EX + f"成功取消代理模式")
     else:
+        port = pt
         proxies = {
             "http://": f"http://127.0.0.1:{port}",
             "https://": f"http://127.0.0.1:{port}"
         }
         logger.success(Fore.LIGHTCYAN_EX + f"当前本地代理端口：{port}")
 
-    await set_port.finish("本地代理端口设置成功，设置将在下一次请求时启用")
+        await set_port.finish("本地代理端口设置成功，设置将在下一次请求时启用")
 
 
 # 设置后端URL
@@ -126,7 +135,7 @@ async def _(event: MessageEvent, bot: Bot, regex=RegexGroup()):
     name = (await bot.get_stranger_info(user_id=int(id_)))["nickname"]
 
     await process_img.send(Message(fr"[CQ:at,qq={id_}]正在生成图片，请稍等..."))
-    logger.info(Fore.LIGHTYELLOW_EX + f"\n开始生成{name}的图片：\nsize={size[0]}，{size[1]}\nprompt={prompt}")
+    logger.info(Fore.LIGHTYELLOW_EX + f"\n开始生成{name}的图片：\nsize={size[0]},{size[1]}\nprompt={prompt}")
     switch = False
     data = await get_data(post_url=post_url, size=size, prompt=prompt, proxies=proxies)
 
@@ -160,6 +169,37 @@ async def _(event: MessageEvent, bot: Bot):
         switch = True
         await img2img.finish("缺少参数！")
     else:
+
+        try:
+            # 获取strength
+            strength = findall(r'strength=(?P<strength>\d\.\d)', info)[0]
+        except IndexError:
+            strength = 0.7
+        else:
+            try:
+                fs = float(strength)
+            except ValueError:
+                await img2img.finish("请输入正确的strength！")
+            else:
+                strength = fs
+            if strength > 0.99:
+                await img2img.finish("strength过大！（不能超过0.99）")
+
+        try:
+            # 获取noise
+            noise = findall(r'noise=(?P<noise>\d\.\d)', info)[0]
+        except IndexError:
+            noise = 0.2
+        else:
+            try:
+                fn = float(noise)
+            except ValueError:
+                await img2img.finish("请输入正确的noise！")
+            else:
+                noise = fn
+            if noise > 0.99:
+                await img2img.finish("noise过大！（不能超过0.99）")
+
         # 处理图片尺寸
         try:
             size = size.split("x")
@@ -209,8 +249,10 @@ async def _(event: MessageEvent, bot: Bot):
         img = b64encode(img_data[1]).decode("utf-8")
         mode = "以图生图"
         switch = False
-        logger.info(Fore.LIGHTYELLOW_EX + f"\n开始生成{name}的图片：\nsize={size[0]}，{size[1]}\nprompt={prompt}")
-        data = await get_data(post_url, size, prompt, proxies, img, mode)
+        logger.info(Fore.LIGHTYELLOW_EX +
+                    f"\n开始生成{name}的图片：\nsize={size[0]},{size[1]}\nstrength={strength}\nnoise={noise}\nprompt={prompt}")
+        data = await get_data(post_url=post_url, size=size, prompt=prompt, proxies=proxies, img=img, mode=mode,
+                              strength=strength, noise=noise)
 
         if data[0] is False:
             switch = True
